
/**
 * Title:        VeniVidiVinci<p>
 * Description:  An applet that displays visualisations of data sets and allows
 * these visualisations to be manipulated and selections made<p>
 * Copyright:    Copyright (c) Matthew Carey<p>
 * Company:      Imperial College<p>
 * @author Matthew Carey
 * @version 1.0
 */
package vishnu.testvis.visual;

import javax.swing.*;
import javax.swing.plaf.basic.*;
import java.awt.*;
import java.awt.event.*;


/** Panel containing the graphical search interface */
public class SimplePanel extends JPanel {

    JTextField textField;
    Vishnu currentMain;


    public class InfoLabel extends JLabel {
        void update() {
            int startIndex = localHLinkPanel.index +1;
            int endIndex = localHLinkPanel.index + localHLinkPanel.numDisplayedDocs;
            int numDocs = currentMain.dataManager.getDocCount();
            if (numDocs < endIndex) endIndex = numDocs;

            setText("Documents "+ startIndex + "-" + endIndex + " out of " + numDocs);
        }

    }

    InfoLabel infoLabel = new InfoLabel();

    Hlink localHLinkPanel;

    JButton backButton, nextButton;
    public SimplePanel(Vishnu theMain)
    {
        this.currentMain = theMain;
        localHLinkPanel = new Hlink(600,400,currentMain);
        try
        {
            jbInit();
        }
        catch(Exception e)
        {
            e.printStackTrace();
        }
    }
    public SimplePanel()

    {
        this.currentMain = null;
        localHLinkPanel = new Hlink();
        try
        {
            jbInit();
        }
        catch(Exception e)
        {
            e.printStackTrace();
        }
    }
    private void jbInit() throws Exception
    {
        setName("Simple ");


        backButton = new JButton("<<");
        backButton.setBorder(BorderFactory.createEtchedBorder());
        backButton.setEnabled(false);
        backButton.addMouseListener( new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {

                if (!backButton.isEnabled()) return;

                nextButton.setEnabled(true);

                localHLinkPanel.index -= localHLinkPanel.numDisplayedDocs;
                localHLinkPanel.update();
                infoLabel.update();

                if (localHLinkPanel.index == 0) {
                    backButton.setEnabled(false);
                }
            }
        });
        nextButton = new JButton(">>");
        nextButton.setBorder(BorderFactory.createEtchedBorder());
        nextButton.setEnabled(false);
        nextButton.addMouseListener( new MouseAdapter()
        {
            public void mouseClicked(MouseEvent e)
            {

                if (!nextButton.isEnabled()) return;

                backButton.setEnabled(true);

                localHLinkPanel.index += localHLinkPanel.numDisplayedDocs;
                localHLinkPanel.update();
                infoLabel.update();

                if (localHLinkPanel.index + localHLinkPanel.numDisplayedDocs >= currentMain.dataManager.getDocCount())
                {
                    nextButton.setEnabled(false);
                }
            }
        });

        //

        // Set the new layout
        GridBagLayout gridBag = new GridBagLayout();
        setLayout(gridBag);

        GridBagConstraints constraints = new GridBagConstraints();

        constraints.fill = GridBagConstraints.BOTH;
        constraints.insets = new Insets(10,3,10,3);
        constraints.ipadx = 0;
        constraints.ipady = 8;



        // Link panel
        constraints.ipady = 4;
        constraints.gridx = 0;
        constraints.gridy = GridBagConstraints.RELATIVE;
        constraints.gridwidth = GridBagConstraints.REMAINDER;
        constraints.gridheight = 8;

        gridBag.setConstraints(localHLinkPanel.linkPane,constraints);
        add(localHLinkPanel.linkPane);

        // Info label
        constraints.gridx = 0;
        constraints.gridy = GridBagConstraints.RELATIVE;
        constraints.gridwidth = 6;
        constraints.gridheight = GridBagConstraints.REMAINDER;

        infoLabel.setMinimumSize(new Dimension(500,20));
        infoLabel.setMaximumSize(new Dimension(500,20));
        gridBag.setConstraints(infoLabel,constraints);
        add(infoLabel);

        // Back button

        constraints.fill = GridBagConstraints.NONE;
        constraints.gridx = GridBagConstraints.RELATIVE;
        constraints.gridy = 9;
        constraints.gridwidth = 2;
        constraints.gridheight = GridBagConstraints.REMAINDER;

        Dimension buttonDimension = new Dimension(55,30);
        backButton.setMaximumSize(buttonDimension);
        backButton.setPreferredSize(buttonDimension);
        backButton.setMinimumSize(buttonDimension);

        gridBag.setConstraints(backButton,constraints);
        add(backButton);

        // Next button
        constraints.gridx = GridBagConstraints.RELATIVE;
        constraints.gridy = 9;
        constraints.gridwidth = 2;
        constraints.gridheight = GridBagConstraints.REMAINDER;


        nextButton.setMaximumSize(buttonDimension);
        nextButton.setPreferredSize(buttonDimension);
        nextButton.setMinimumSize(buttonDimension);

        gridBag.setConstraints(nextButton,constraints);
        add(nextButton);

        // Global layout
        setSize(600,400);
        setPreferredSize(new Dimension(600,400));
        setMinimumSize(new Dimension(600,400));

        setVisible(true);
    }


    public void update() {

        localHLinkPanel.index = 0;

        infoLabel.update();
        localHLinkPanel.update();

        if (currentMain.dataManager.getDocCount() > localHLinkPanel.numDisplayedDocs) {
            nextButton.setEnabled(true);
        }

    }

}
