/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Author: Chi-Yu Huang, Greenstone Digital Library, University of Waikato
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
// Graphical Adminstration Interface
package org.greenstone.admin;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.net.*;
import java.util.*;
import javax.swing.*;
import javax.swing.plaf.*;
import javax.swing.text.*;

import org.greenstone.admin.GAIManager;
import org.greenstone.core.Configuration;
import org.greenstone.core.Dictionary;
import org.greenstone.admin.gui.SetServerPane;

/** Containing the top-level "core" for the GAI(Graphical Administration
 * Interface) this class is the common core for the GAI application and 
 * applet. It first parses the command line arguments, preparing to update 
 * the configuration as required. Next it loads several important support 
 * classes such as the Configuration and Dictionary. Finally it creates the 
 * other important managers and sends them on their way.
 * @author Chi-Yu Huang, Greenstone Digital Library, University of Waikato
 * @version ###
 */
public class GAI
{
    public static Dimension screen_size = Toolkit.getDefaultToolkit().getScreenSize();
    public static String gsdl3_path;
    public static String admin_path;
    public static String tomcat_file_path;
    public static String images_path;
    public static File build_file;
    public static File site_conf;
    public static File interface_conf;
    /** A public reference to the GAIManager. */
    static public GAIManager ga_man;

    public GAI()
    {
	this.gsdl3_path = gsdl3_path;
	this.admin_path = this.gsdl3_path + "/src/java/org/greenstone/admin/";
	this.tomcat_file_path = this.gsdl3_path + "/comms/jakarta/tomcat/logs/";
	this.images_path = this.admin_path + "images/";
       	this.build_file = new File(gsdl3_path, "build.properties"); 
	this.site_conf = new File (gsdl3_path,"/web/sites/localsite/siteConfig.xml");
	this.interface_conf = new File (gsdl3_path, "/web/interfaces/default/interfaceConfig.xml");
	init();
    }
    
    public static void main (String[] args){
	gsdl3_path = args[0];
	admin_path = gsdl3_path + "/src/java/org/greenstone/admin/";
	new Configuration (admin_path);
	GAI gai = new GAI();
	
	ga_man  = new GAIManager(screen_size);
	ga_man.display();
    }

    public void init (){
	// Read Dictionary
	new Dictionary(Configuration.getLocale("general.locale", true), Configuration.getFont("general.font", true));

    }
}


